@@ -1118,7 +1118,6 @@ class MainWindow(QtG.QMainWindow):
                 self.moving_box.getRect().set_y(y)
 
                 self.fig.canvas.restore_region(self.background_current)
-
                 ## draw all boxes again
                 self._draw_all_boxes()
 
@@ -1221,7 +1220,7 @@ class MainWindow(QtG.QMainWindow):
         a = np.array([x, y])
 
         for box in rectangles:
-            b = np.array(box.xy)
+            b = np.array(box.getRect().xy)
             dist = np.linalg.norm(a - b)
             if get_low:
                 if (
